@@ -581,7 +581,9 @@ class Library(object):
                 name = self.package + "_" + name
 
         # Convert boolean values to "Yes"/"No"
-        data = data.replace({True: "Yes", False: "No"})
+        for col in data:
+            if data[col].dtype == bool:
+                data[col] = data[col].map({True: "Yes", False: "No"})
             
         # Check if running in a SyncroSim environment from the user interface
         e = _environment()
